@@ -61,16 +61,22 @@ def bootstrap_javascript_tag(name):
     return u'<script src="%s"></script>' % bootstrap_javascript_url(name)
 
 @register.filter
-def as_bootstrap(form_or_field, layout='vertical'):
+def as_bootstrap(form_or_field, layout='vertical,false'):
     """
     Render a field or a form according to Bootstrap guidelines
     """
-    layout = str(layout).lower()
+    params = split(layout, ",")
+    layout = str(params[0]).lower()
+
+    if len(params) > 1:
+        float = str(params[1]).lower() == "float"
+
     if isinstance(form_or_field, BaseForm):
         return get_template("bootstrap_toolkit/form.html").render(
             Context({
                 'form': form_or_field,
                 'layout': layout,
+                'float': float,
             })
         )
     elif isinstance(form_or_field, BoundField):
@@ -78,6 +84,7 @@ def as_bootstrap(form_or_field, layout='vertical'):
             Context({
                 'field': form_or_field,
                 'layout': layout,
+                'float': float,
             })
         )
     else:
